@@ -1,17 +1,14 @@
-use openssl::ecdsa::EcdsaSig;
-use openssl::sha::sha256;
-use serde::Serialize;
-use std::collections::VecDeque;
-use std::{
-    convert::TryInto,
-    sync::Arc,
-};
-use tokio::sync::Mutex;
 use crate::acc::AcmeKey;
 use crate::error;
 use crate::jwt::*;
 use crate::req::{req_expect_header, req_head, req_post};
 use crate::util::base64url;
+use openssl::ecdsa::EcdsaSig;
+use openssl::sha::sha256;
+use serde::Serialize;
+use std::collections::VecDeque;
+use std::{convert::TryInto, sync::Arc};
+use tokio::sync::Mutex;
 
 /// JWS payload and nonce handling for requests to the API.
 ///
